@@ -2,9 +2,9 @@
 # Copyright (c) Max-Planck-Institut für Eisenforschung GmbH - Computational Materials Design (CM) Department
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 
+# API of the pyiron_base module
 from pyiron_base.generic.hdfio import FileHDFio, ProjectHDFio
 from pyiron_base.generic.inputlist import InputList
-from pyiron_base.generic.jedi import fix_ipython_autocomplete
 from pyiron_base.generic.parameters import GenericParameters
 from pyiron_base.generic.template import PyironObject
 from pyiron_base.job.executable import Executable
@@ -15,6 +15,7 @@ from pyiron_base.job.jobstatus import JobStatus, job_status_successful_lst, job_
 from pyiron_base.job.jobtype import JOB_CLASS_DICT, JobType, JobTypeChoice
 from pyiron_base.job.template import TemplateJob
 from pyiron_base.master.generic import GenericMaster, get_function_from_string
+from pyiron_base.master.list import ListMaster
 from pyiron_base.master.parallel import ParallelMaster, JobGenerator
 from pyiron_base.master.serial import SerialMasterBase
 from pyiron_base.project.generic import Project
@@ -23,15 +24,19 @@ from pyiron_base.server.queuestatus import validate_que_request
 from pyiron_base.settings.generic import Settings
 from pyiron_base.settings.install import install_dialog
 
+# optional API of the pyiron_base module
 try:
-    from pyiron_base import ProjectGUI
+    from pyiron_base.project.gui import ProjectGUI
 except (ImportError, TypeError, AttributeError):
     pass
 
+# Internal init
 from ._version import get_versions
+from pyiron_base.generic.jedi import fix_ipython_autocomplete
 
+# Set version of pyiron_base
 __version__ = get_versions()["version"]
 del get_versions
 
-# jedi fix
+# Jedi fix
 fix_ipython_autocomplete()
